@@ -3,10 +3,13 @@
 from . import version
 from .core import Pooch, create, retrieve
 from .utils import os_cache, file_hash, make_registry, check_version, get_logger
-from .downloaders import HTTPDownloader, FTPDownloader
+from .downloaders import HTTPDownloader, FTPDownloader, SFTPDownloader
 from .processors import Unzip, Untar, Decompress
 
 
+__version__ = version.full_version
+
+
 def test(doctest=True, verbose=True, coverage=False):
     """
     Run the test suite.
